summaryrefslogtreecommitdiff
path: root/test/unit/util/assert_white.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'test/unit/util/assert_white.cpp')
-rw-r--r--test/unit/util/assert_white.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/test/unit/util/assert_white.cpp b/test/unit/util/assert_white.cpp
index 0f1d5786e..a64bf275d 100644
--- a/test/unit/util/assert_white.cpp
+++ b/test/unit/util/assert_white.cpp
@@ -9,9 +9,9 @@
** All rights reserved. See the file COPYING in the top-level source
** directory for licensing information.\endverbatim
**
** \brief White box testing of CVC4::Configuration.
**
** White box testing of CVC4::Configuration.
**/
#include <cstring>
@@ -20,7 +20,7 @@
#include "base/check.h"
#include "test.h"
-namespace CVC4 {
+namespace CVC5 {
namespace test {
class TestUtilWhite : public TestInternal
@@ -86,4 +86,4 @@ TEST_F(TestUtilWhite, CheckArgument)
ASSERT_THROW(CheckArgument(false, "x"), IllegalArgumentException);
}
} // namespace test
-} // namespace CVC4
+} // namespace CVC5
generated by cgit on debian on lair
contact matthew@masot.net with questions or feedback
@@ -9,9 +9,9 @@
** directory for licensing information.\endverbatim
**
- ** \brief White box testing of CVC4::Configuration.
+ ** \brief White box testing of CVC5::Configuration.
**
@@ -9,9 +9,9 @@
**
- ** White box testing of CVC4::Configuration.
+ ** White box testing of CVC5::Configuration.
**/
#include <cstring>